@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: test-framework
 version: 0.8.1.1
-id: test-framework-0.8.1.1-629076a409d4c76bf9cfaeeb28bad811
-key: testf_4H0ct1ddVB2I2MqugXDYyk
+id: test-framework-0.8.1.1-a9fe3ef1175e4639905fc641f904c6e2
+key: testf_B1MVPJUrcmB7HNAGf4Uv93
 license: BSD3
 maintainer: Libraries List <libraries@haskell.org>
 homepage: https://batterseapower.github.io/test-framework/
@@ -36,7 +36,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/test-framework-0.8.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/test-framework-0.8.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/test-framework-0.8.1.1
-hs-libraries: HStest-framework-0.8.1.1-4H0ct1ddVB2I2MqugXDYyk
+hs-libraries: HStest-framework-0.8.1.1-B1MVPJUrcmB7HNAGf4Uv93
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
@@ -47,7 +47,7 @@ depends:
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     regex-posix-0.95.2-7db894a782ed7a4a4d46c02c0db4ce39
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    xml-1.3.14-47d6d03c8a900e03cf8951206101564b
+    xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
 haddock-interfaces: /usr/share/doc/haskell-test-framework/html/test-framework.haddock
 haddock-html: /usr/share/doc/haskell-test-framework/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
